diff --git a/engines/scumm/script.cpp b/engines/scumm/script.cpp
index cfc4b3c..a7fae96 100644
--- a/engines/scumm/script.cpp
+++ b/engines/scumm/script.cpp
@@ -576,6 +576,8 @@ int ScummEngine::readVar(uint var) {
 					return 0;
 				} else if (_game.id == GID_ZAK && (_game.platform == Common::kPlatformFMTowns) && var == 151 && bit == 8) {
 					return 0;
+				} else if (_game.id == GID_INDY3 && (_game.platform == Common::kPlatformAmiga) && var == 94 && bit == 4) {
+					return 0;
 				}
 			}
 
diff --git a/engines/scumm/script_v5.cpp b/engines/scumm/script_v5.cpp
index a6cf504..3574c3f 100644
--- a/engines/scumm/script_v5.cpp
+++ b/engines/scumm/script_v5.cpp
@@ -1286,6 +1286,17 @@ void ScummEngine_v5::o5_loadRoom() {
 
 	room = getVarOrDirectByte(PARAM_1);
 
+	if (!_copyProtection) {
+		if (_game.id == GID_INDY3 && (_game.platform == Common::kPlatformAmiga) && (_scriptPointer - _scriptOrgPointer == 0x5BD) ) {
+			/* Move the pointer past the copyprotection check. This code is
+			   encountered when the users wants to skip the cutscene where
+			   Indy meets Marcus for the first time.
+			*/
+			_scriptPointer+=0x6;
+			return;
+		}
+	}
+
 	// For small header games, we only call startScene if the room
 	// actually changed. This avoid unwanted (wrong) fades in Zak256
 	// and others. OTOH, it seems to cause a problem in newer games.
@@ -1419,6 +1430,16 @@ void ScummEngine_v5::o5_print() {
 }
 
 void ScummEngine_v5::o5_printEgo() {
+
+	if (!_copyProtection) {
+		if (_game.id == GID_INDY3 && (_game.platform == Common::kPlatformAmiga) && (_scriptPointer - _scriptOrgPointer == 0x407) ) {
+			/* Move the pointer past the copyprotection check, so it looks
+			   the same as the steam version. Not neccesary since we already
+			   fixed the copyprotection elsewhere, but it looks nicer because
+			   it's now completely hidden. */
+			_scriptPointer+=0x11C;
+		}
+	}
 	_actorToPrintStrFor = (byte)VAR(VAR_EGO);
 	decodeParseString();
 }
